use super::*;

#[derive(serde::Serialize, PartialOrd, PartialEq, Ord, Eq)]
pub struct LineRange {
    pub start: LineNumber,
    pub end: LineNumber,
}
